@@ -19,12 +19,34 @@
 
 """
 
+class AccountDoesNotExist(Exception):
+    """The requested user does not exist."""
+    pass
 
-class ObjectDoesNotExist(Exception):
-    """The requested object does not exist"""
-    silent_variable_failure = True
+class InvalidGroupDN(Exception):
+    """The Group DN provided is invalid."""
+    pass
 
-    
 class ImproperlyConfigured(Exception):
-    """LDAP Groups is somehow improperly configured"""
+    """LDAP Groups is somehow improperly configured."""
+    pass
+
+class InvalidCredentials(ImproperlyConfigured):
+    """The bind dn and password provided are invalid."""
+    pass
+
+class LDAPServerUnreachable(Exception):
+    """The LDAP server is unreachable."""
+    pass
+
+class ModificationFailed(Exception):
+    """The AD Group could not be modified."""
+    pass
+
+class AccountAlreadyExists(ModificationFailed):
+    """The account name provided already exists in a group being modified."""
+    pass
+
+class InsufficientPermissions(ModificationFailed):
+    """The bind user does not have permission to modify a group."""
     pass
\ No newline at end of file
